/*
 * AkamaiMediaAnalytics.swift
 * Version - 0.1
 *
 * This file is part of the Media Analytics, http://www.akamai.com
 * Media Analytics is a proprietary Akamai software that you may use and modify per the license agreement here:
 * http://www.akamai.com/product/licenses/mediaanalytics.html
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 *
 *
 * Created by El Visy on 8th May 2017.
 *
 */


import Foundation

@objc public final class AkamaiMediaAnalytics: NSObject{

  /// Internal implementation of the Media Analytics Library
  fileprivate let mediaAnalyticsImplementation: AkamaiMediaAnalyticsInternal

  /// a flag to differentiate between API based and loader based integration
  fileprivate var loaderBasedIntegration = false

  /// a constant for text "API"
  private let api = "API"

  /// a constant for text "methodName"
  private let methodName = "methodName"

  /// a constant for text "parameters"
  private let parameters = "parameters"

  /// a constant for text "parameters"
  private let reportAPI = "reportAPI"


  // MARK: - Lifecycle Methods
  /**
   Creates an instance of the AkamaiMediaAnalytics

   - Parameter configURL: The configuration/Beacon XML path
   */
  @objc public init (configurationUrl configURL : String){
    mediaAnalyticsImplementation = AkamaiMediaAnalyticsInternal(configurationUrl: configURL)
  }

  deinit{
  }

  /**
   This call starts all metric calculations.

   - Parameter dataProvider: The object implementing AkamaiPlayerDataProtocol interface.
   - Parameter streamUrl: The url of the stream being played
   */
  @objc(handleSessionInit:withStreamUrl:)
  public func handleSessionInit(playerDataProvider dataProvider :AkamaiPlayerDataProtocol, stream streamUrl:String){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleSessionInit(dataProvider)", type : api)
      let validatorInput = [methodName : "handleSessionInit", parameters : [ "akamaiCallbacks" : [] ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleSessionInit(playerDataProvider:dataProvider, stream: streamUrl)
  }

  /**
   This method triggers calculation of play start metrics. This must be called immediately after the player has
   started to play the video.
   */
  @objc public func handlePlaying(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handlePlaying()", type : api)
      let validatorInput = [methodName : "handlePlaying", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handlePlaying()
  }

  /**
   This method must be called when player enters buffering state.
   */
  @objc public func handleBufferStart(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleBufferStart()", type : api)
      let validatorInput = [methodName : "handleBufferStart", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleBufferStart()
  }

  /**
   This method must be called when player exits buffering state and starts playing.
   */
  @objc public func handleBufferEnd(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleBufferEnd()", type : api)
      let validatorInput = [methodName : "handleBufferEnd", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleBufferEnd()
  }

  /**
   This method must be called when player is paused.
   */
  @objc public func handlePause(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handlePause()", type : api)
      let validatorInput = [methodName : "handlePause", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handlePause()
  }

  /**
   This method must be called when seek is performed on the video.
   */
  @objc public func handleSeek(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleSeek()", type : api)
      let validatorInput = [methodName : "handleSeek", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleSeek()
  }

  /**
   This method must be called when player encounters an error and stops playing

   - Parameter error: The error which caused the playback to end.
   */
  @objc(handleError:)
  public func handleError(errorReason error :String){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleError(" + error + ")", type : api)
      let validatorInput = [methodName : "handleError", parameters : ["errorMessage" : error]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleError(errorReason: error)
  }

  /**
   This method must be called when play back completed successfully

   - Parameter endReasonCode: The reason for completion of video. (playback completed etc.)
   */
  @objc(handlePlayEnd:)
  public func handlePlayEnd(endReason endReasonCode :String){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handlePlayEnd(" + endReasonCode + ")", type : api)
      let validatorInput = [methodName : "handlePlayEnd", parameters : ["errorMessage" : endReasonCode]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handlePlayEnd(endReason: endReasonCode)
  }

  @available(*, deprecated, message: "This API and will be removed soon and is no longer required to be called.")
  /**
   Calls visit on mediaAnalyticsImplementation.
   */
  public func handleVisit(){
  }

  /**
   Handles title switch. All we have to do is set custom dimensions and set
   isFirstTitle = 0
   */
  @objc(handleTitleSwitch:)
  public func handleTitleSwitch(newDimensions customData:[String:String]){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleTitleSwitch(customData)", type : api)
      let validatorInput = [methodName : "handleTitleSwitch", parameters : ["customData" : customData ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleTitleSwitch(newDimensions:customData)
  }

  /// Ad apis
  /**
   This call must be made just when the Ad is loaded into the player.
   
   - Parameter adInfo: a dictionary containing ad load related information
   */
  @objc(handleAdLoaded:)
  public func handleAdLoaded(adParam adInfo:[String: String]){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleAdLoaded(adInfo)", type : api)
      let validatorInput = [methodName : "handleAdLoaded", parameters : ["adInfoObject" : [] ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleAdLoaded(adParam: adInfo)
  }
  
  /**
   This call should be made just when the Ad starts playing.
   
   - Parameter adInfo: a dictionary containing ad start related information
   */
  @objc(handleAdStarted:)
  public func handleAdStarted(adParam adInfo:[String: String]){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleAdStarted(adInfo)", type : api)
      let validatorInput = [methodName : "handleAdStarted", parameters : ["adInfoObject" : [] ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleAdStarted(adParam: adInfo)
  }
  
  /**
   This call should be made when 25% of Ad has played.
   */
  @objc public func handleAdFirstQuartile(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleAdFirstQuartile()", type : api)
      let validatorInput = [methodName : "handleAdFirstQuartile", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleAdFirstQuartile()
  }
  
  /**
   This call should be made when 50% of Ad has played.
   */
  @objc public func handleAdMidPoint(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleAdMidPoint()", type : api)
      let validatorInput = [methodName : "handleAdMidPoint", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleAdMidPoint()
  }
  
  /**
   This call should be made when 75% of Ad has played.
   */
  @objc public func handleAdThirdQuartile(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleAdThirdQuartile()", type : api)
      let validatorInput = [methodName : "handleAdThirdQuartile", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleAdThirdQuartile()
  }
  
  /**
   This call is made when the ad has completely played.
   */
  @objc public func handleAdComplete(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleAdComplete()", type : api)
      let validatorInput = [methodName : "handleAdComplete", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleAdComplete()
  }
  
  
  /**
   This call should be made when the Ad has been stopped/closed/skipped by the user.
   */
  @objc public func handleAdSkipped(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleAdSkipped()", type : api)
      let validatorInput = [methodName : "handleAdSkipped", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleAdSkipped()
  }
  
  /**
   This call should be made when an error occurs while playing the Ad.
   */
  @objc public func handleAdError(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleAdError()", type : api)
      let validatorInput = [methodName : "handleAdError", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleAdError()
  }

  @available(*, deprecated, message: "This API and will be removed soon, MA Library handles Application Foreground on it's own")
  /**
   This call should be made when App is relaunched from background
   */
  public func handleApplicationForeground(){
  }


  /**
   This call should be made when an App goes to background or closed
   */
  @available(*, deprecated, message: "Undocumented API and will soon become unavailable, refer Managing Application Background and Foreground section of the integration guide")
  public func handleAdAppClosedBackground(){
  }

  /**
   The method to be called when the application quits.
   */
  @objc public func handleApplicationExit(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleApplicationExit()", type : api)
      let validatorInput = [methodName : "handleApplicationExit", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleApplicationExit()
  }

  @available(*, deprecated: 3.3, message: "This API will be removed soon, use handleBitrateSwitch() instead")
  /**
   This method must be called either when bit rate of the video changes or bit rate information becomes available.

   - Parameter newBitRate: The bit rate currently served (Bit rate in bits per second).
   */
  @objc(handleBitrateChange:)
  public func handleBitrateChange(bitRate newBitRate: Int64){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleBitrateChange(" + String(newBitRate) + ")", type : api)
      let validatorInput = [methodName : "handleBitrateChange", parameters : [ "newBitRate" : newBitRate ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleBitrateSwitch(bitRate: newBitRate)
  }

  /**
   This method must be called either when bit rate of the video changes or bit rate information becomes available.

   - Parameter newBitRate: The bit rate currently served (Bit rate in bits per second).
   */
  @objc(handleBitrateSwitch:)
  public func handleBitrateSwitch(bitRate newBitRate: Int64){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "handleBitrateSwitch(" + String(newBitRate) + ")", type : api)
      let validatorInput = [methodName : "handleBitrateSwitch", parameters : [ "newBitRate" : newBitRate ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.handleBitrateSwitch(bitRate: newBitRate)
  }
  /**
   This method can be called to set custom data on the plugin. Ideally should be called before handleSessionInit

   - Parameter keyInfo: Dimension name to be set
   - Parameter data: Value to be reported for the dimension.
   */
  @objc(setData:value:)
  public func setData(key keyInfo:String, forValue data:String){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "setData(" + keyInfo + "," + data + ")", type : api)
      let validatorInput = [methodName : "setData", parameters : [ "key" : keyInfo,"value" : data ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.setData(key: keyInfo, forValue: data)
  }

  /**
  This method can be called to set stream length
  - Parameter duration: length of the stream in seconds
  */
  @objc(setStreamDuration:)
  public func setStreamDuration(duration:Int64){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "setStreamDuration(" + String(duration) + ")", type : api)
      let validatorInput = [methodName : "setStreamDuration", parameters : [ "duration" : duration/1000 ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.setStreamLength(duration: duration)
  }

  /**
   This method can be called for setting veiwerId.

   - Parameter viewerId: The viewerId to be set.
   */
  @objc(setViewerId:)
  public func setViewerId(uniqueViewerId viewerId:String){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "setViewerId(" + viewerId + ")", type : api)
      let validatorInput = [methodName : "setViewerId", parameters : ["viewerId" : viewerId ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.setViewerId(uniqueViewerId: viewerId)
  }

  @available(*, deprecated: 3.3, message: "This API and will be removed soon, use setViewerDiagnosticsId() instead")
  /**
   This method can be called for setting veiwer diagnostic Id.

   - Parameter diagnosticId: The viewer diagnostic Id to be set.
   */
  @objc(setViewerDiagnosticId:)
  public func setViewerDiagnosticId(uniqueDiagnosticId diagnosticId:String){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "setViewerDiagnosticId(" + diagnosticId + ")", type : api)
      let validatorInput = [methodName : "setViewerDiagnosticId", parameters : ["diagnosticsId" : diagnosticId ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.setViewerDiagnosticsId(uniqueDiagnosticId: diagnosticId)
  }

  /**
   This method can be called for setting veiwer diagnostic Id.

   - Parameter diagnosticId: The viewer diagnostic Id to be set.
   */
  @objc(setViewerDiagnosticsId:)
  public func setViewerDiagnosticsId(uniqueDiagnosticId diagnosticId:String){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "setViewerDiagnosticsId(" + diagnosticId + ")", type : api)
      let validatorInput = [methodName : "setViewerDiagnosticsId", parameters : ["diagnosticsId" : diagnosticId ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.setViewerDiagnosticsId(uniqueDiagnosticId: diagnosticId)
  }

  @available(*, deprecated, message: "This API and will be removed soon, use setData() instead")
  /**
  Set the delivery type of the currently playing stream
  - Parameter deliveryType: Delivery type of the content. Eg. VOD, Live, etc
  */
  public func setDeliveryType(type:String){
    mediaAnalyticsImplementation.setData(key: "deliveryType", forValue: type)
  }

  @available(*, deprecated: 3.3, message: "This API will be removed soon use enableServerIPLookup() instead")
  /**
   Method to turn on reporting of server ip address. This is currently supported only for akamai hosted stream
   */
  @objc public func enableServerIpLookup(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "enableServerIpLookup()", type : api)
      let validatorInput = [methodName : "enableServerIpLookup", parameters : [ : ]] as [String : Any]
      sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.enableServerIPLookup()
  }

  /**
   Method to turn on reporting of server ip address. This is currently supported only for akamai hosted stream
   */
  @objc public func enableServerIPLookup(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "enableServerIPLookup()", type : api)
      let validatorInput = [methodName : "enableServerIPLookup", parameters : [ : ]] as [String : Any]
      sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.enableServerIPLookup()
  }

  @available(*, deprecated: 3.3, message: "This API will be removed soon use disableServerIPLookup() instead")
  /**
   Method to turn off reporting of server ip address. This is currently supported only for akamai hosted stream
   */
  @objc public func disableServerIpLookup(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : " disableServerIpLookup()", type : api)
      let validatorInput = [methodName : " disableServerIpLookup", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.disableServerIPLookup()
  }

  /**
   Method to turn off reporting of server ip address. This is currently supported only for akamai hosted stream
   */
  @objc public func disableServerIPLookup(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : " disableServerIPLookup()", type : api)
      let validatorInput = [methodName : " disableServerIPLookup", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.disableServerIPLookup()
  }

  /**
   Method to turn off reporting of location.
   */
  @objc public func enableLocation(){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "enableLocation()", type : api)
      let validatorInput = [methodName : "enableLocation", parameters : [ : ]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.enableLocation()
  }

  /**
   Method to turn off reporting of location.
   */
  @objc public func disableLocation(){
    if(!loaderBasedIntegration){
      logMessage(message : "disableLocation()", type : api)
      let validatorInput = [methodName : "disableLocation", parameters : [ : ]] as [String : Any]
      sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.disableLocation()
  }

  @available(*, deprecated: 3.3, message: "This API is deprecated will be removed soon.To turn on debug logging use enableDebugLogging() and to turn off use disableDebugLogging() instead")
  /**
   Method to turn on/off beacon reporting

   - Parameter enable: True to turn on the logging, false to turn it off.
   */
  @objc(setDebugLogging:)
  public func setDebugLogging(enableDebug enable:Bool){
    if(!loaderBasedIntegration){
      mediaAnalyticsImplementation.logMessage(message : "setDebugLogging()", type : api)
      let validatorInput = [methodName : "setDebugLogging", parameters : ["enableDebug" : true]] as [String : Any]
      mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : reportAPI, inputValue : validatorInput)
    }
    mediaAnalyticsImplementation.setDebugLogging(enableDebug: enable)
  }

  /**
   Method to turn on debug logs reporting
   */
  @objc public func enableDebugLogging() {
    mediaAnalyticsImplementation.logMessage(message : "enableDebugLogging()", type : api)
    let validatorInput = [methodName : "enableDebugLogging", parameters : [ : ]] as [String : Any]
    mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : "reportAPI", inputValue : validatorInput)
    mediaAnalyticsImplementation.setDebugLogging(enableDebug: true)
  }

  /**
   Method to turn off debug logs reporting
   */
  @objc public func disableDebugLogging() {
    mediaAnalyticsImplementation.logMessage(message : "disableDebugLogging()", type : api)
    let validatorInput = [methodName : "disableDebugLogging", parameters : [ : ]] as [String : Any]
    mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : "reportAPI", inputValue : validatorInput)
    mediaAnalyticsImplementation.setDebugLogging(enableDebug: false)
  }

  /**
   Method to append the loader information to the sdk information.
   - Parameter loaderInformation: Contains the name and version of the loader in a specific format.
   */
  public func setLoaderInformation(loaderInformation:String) {
    loaderBasedIntegration = true
    mediaAnalyticsImplementation.setLoaderInformation(loaderInformation: loaderInformation)
  }

  /**
   This function relays the messages to be logged.
   - Parameter message: The mesaage to be logged or send over to Diagnoser
   - Parameter type: This holds the type of message
   */
  internal func logMessage(message:String ,type:String) {
    mediaAnalyticsImplementation.logMessage(message : message, type : type)
  }

  /**
    This function is used to send API's and it parameters to Diagnoser for validation
    - Parameter inputApi: The API name which will be validated
    - Parameter inputValue: The actual parameters passed to the API.
   */
  internal func sendMessageToDiagnoser(inputApi:String, inputValue:Any) {
    mediaAnalyticsImplementation.sendMessageToDiagnoser(inputApi : inputApi, inputValue : inputValue)
  }
}
